@@ -40,4 +40,8 @@ summary.spwb<-function(object, freq="years", output="WaterBalance", FUN=sum, byS
   M = M[ncases>0, ,drop = FALSE]
   
   return(M)
+}
+
+summary.pwb<-function(object, freq="years", output="WaterBalance", FUN=sum, bySpecies = FALSE, ...){  
+  summary.spwb(object = object, freq = freq, output = output, FUN = FUN, bySpecies = bySpecies, ...)
 }
\ No newline at end of file
